@@ -132,6 +132,65 @@ class InterceptHandler(logging.Handler):
 
 class CustomizeLogger:
 
+    # @classmethod
+    # def make_default_logger(cls, level: Union[str, int] = "INFO"):
+    #     # todo adjust this later to use a ConfigModel
+    #     if isinstance(level, str):
+    #         level = level.upper()
+    #     logger.remove()
+    #     logging.basicConfig(handlers=[InterceptHandler()], level=0)
+
+    #     *options, extra = logger._options
+    #     new_logger = Logger(logger._core, *options, {**extra})
+    #     new_logger.configure(
+    #         handlers=[
+    #             {
+    #                 "sink": sys.stdout,
+    #                 "format": cls.logger_formatter,
+    #                 "enqueue": True,
+    #                 "backtrace": True,
+    #                 "colorize": True,
+    #                 "level": level,
+    #             },
+    #         ],
+    #         levels = [{
+    #             "name": "DEV",
+    #             "no": 19,
+    #             "color": "<blue>",
+    #             "icon": "@"
+    #         }]
+    #     )
+    #     return new_logger
+
+
+        # if not hasattr(logger.__class__, 'dev'):
+        # try:
+        #     dev_level = logger.level(name='DEV', no=19, color="<blue>", icon="@")
+        #     logger.__class__.dev = functools.partialmethod(logger.__class__.log, 'DEV')
+        #     logger.add(
+        #         sys.stdout,
+        #         enqueue=True,
+        #         backtrace=True,
+        #         colorize=True,
+        #         level=19,
+        #         format=cls.logger_formatter,
+        #     )
+        # except Exception as e:
+        #     pass
+        # #     print("Error adding DEV level to logger: ", e) 
+        # #     # pass
+        # logger.add(
+        #     sys.stdout,
+        #     enqueue=True,
+        #     backtrace=True,
+        #     colorize=True,
+        #     level=level,
+        #     format=cls.logger_formatter,
+        # )
+        # logging.basicConfig(handlers=[InterceptHandler()], level=0)
+        # *options, extra = logger._options
+        # return Logger(logger._core, *options, {**extra})
+
     @classmethod
     def make_default_logger(cls, level: Union[str, int] = "INFO"):
         # todo adjust this later to use a ConfigModel
@@ -184,11 +243,16 @@ class CustomizeLogger:
                 status = record['extra'].get('status')
                 color = STATUS_COLOR.get(status, FALLBACK_STATUS_COLOR)
                 kind_color = STATUS_COLOR.get(record.get('extra', {}).get('kind'), FALLBACK_STATUS_COLOR)
-                extra = '<cyan>{extra[queue_name]}</>:<' + kind_color + '>{extra[kind]:<9}</><' + color + '>{extra[job_id]}</> '
+                if not record['extra'].get('worker_name'):
+                    record['extra']['worker_name'] = ''
+                extra = '<cyan>{extra[queue_name]}</>:<bold><blue>{extra[worker_name]}</></>:<bold><' + kind_color + '>{extra[kind]:<9}</></> <' + color + '>{extra[job_id]}</> '
 
             elif record['extra'].get('kind') and record['extra'].get('queue_name'):
+                if not record['extra'].get('worker_name'):
+                    record['extra']['worker_name'] = ''
                 kind_color = STATUS_COLOR.get(record.get('extra', {}).get('kind'), FALLBACK_STATUS_COLOR)
-                extra = '<cyan>{extra[queue_name]}</>:<' + kind_color + '>{extra[kind]:<9}</> '
+                extra = '<cyan>{extra[queue_name]}</>:<b><blue>{extra[worker_name]}</></>:<b><' + kind_color + '>{extra[kind]:<9}</></> '
+
 
         if 'result=tensor([' not in str(record['message']):
             return "<level>{level: <8}</> <green>{time:YYYY-MM-DD HH:mm:ss.SSS}</>: "\
